@@ -311,7 +311,7 @@ sub _fork_schedule {
          POSIX::_exit (0);
          exit 1;
          
-      } elsif (($! != &Errno::EAGAIN && $! != &Errno::ENOMEM) || !$forks) {
+      } elsif (($! != &Errno::EAGAIN && $! != &Errno::EWOULDBLOCK && $! != &Errno::ENOMEM) || !$forks) {
          # we ignore some errors as long as we can run at least one job
          # maybe we should wait a few seconds and retry instead
          die "fork_call: $!";
@@ -354,17 +354,13 @@ Sets the blocking state of the given filehandle (true == nonblocking,
 false == blocking). Uses fcntl on anything sensible and ioctl FIONBIO on
 broken (i.e. windows) platforms.
 
+Instead of using this function, you could use C<AnyEvent::fh_block> or
+C<AnyEvent::fh_unblock>.
+
 =cut
 
 BEGIN {
-   *fh_nonblocking = AnyEvent::WIN32
-      ? sub($$) {
-          ioctl $_[0], 0x8004667e, pack "L", $_[1]; # FIONBIO
-        }
-      : sub($$) {
-          fcntl $_[0], AnyEvent::F_SETFL, $_[1] ? AnyEvent::O_NONBLOCK : 0;
-        }
-   ;
+   *fh_nonblocking = \&AnyEvent::_fh_nonblocking;
 }
 
 =item $guard = guard { CODE }
@@ -472,7 +468,8 @@ when the program exits I<and> all redirected file descriptors have been
 exhausted.
 
 The C<$cmd> is either a single string, which is then passed to a shell, or
-an arrayref, which is passed to the C<execvp> function.
+an arrayref, which is passed to the C<execvp> function (the first array
+element is used both for the executable name and argv[0]).
 
 The key-value pairs can be:
 
@@ -488,6 +485,12 @@ Redirects program standard output into the specified filename, similar to C<<
 Appends program standard output to the referenced scalar. The condvar will
 not be signalled before EOF or an error is signalled.
 
+Specifying the same scalar in multiple ">" pairs is allowed, e.g. to
+redirect both stdout and stderr into the same scalar:
+
+    ">"  => \$output,
+    "2>" => \$output,
+
 =item ">" => $filehandle
 
 Redirects program standard output to the given filehandle (or actually its
@@ -564,7 +567,7 @@ Example: run F<openssl> and create a self-signed certificate and key,
 storing them in C<$cert> and C<$key>. When finished, check the exit status
 in the callback and print key and certificate.
 
-   my $cv = run_cmd [qw(openssl req 
+   my $cv = run_cmd [qw(openssl req
                      -new -nodes -x509 -days 3650
                      -newkey rsa:2048 -keyout /dev/fd/3
                      -batch -subj /CN=AnyEvent
